# constants.py
# This module contains a list of mathematical and physical constants.

# Pi (π), the ratio of a circle's circumference to its diameter
PI = 3.141592653589793

# Speed of light in vacuum (m/s)
SPEED_OF_LIGHT = 299_792_458

# Gravitational constant (m^3 kg^-1 s^-2)
GRAVITATIONAL_CONSTANT = 6.67430e-11

# Planck's constant (J·s)
PLANCK_CONSTANT = 6.62607015e-34

# Reduced Planck's constant (J·s)
REDUCED_PLANCK_CONSTANT = PLANCK_CONSTANT / (2 * PI)
HBAR = REDUCED_PLANCK_CONSTANT

# Elementary charge (C)
ELEMENTARY_CHARGE = 1.602176634e-19
E = ELEMENTARY_CHARGE

# Boltzmann constant (J/K)
BOLTZMANN_CONSTANT = 1.380649e-23
KB = BOLTZMANN_CONSTANT

# Avogadro's number (1/mol)
AVOGADRO_CONSTANT = 6.02214076e23

# Gas constant (J/(mol·K))
GAS_CONSTANT = 8.314462618

# Electron mass (kg)
ELECTRON_MASS = 9.10938356e-31
EM = ELECTRON_MASS

# Proton mass (kg)
PROTON_MASS = 1.67262192369e-27

# Neutron mass (kg)
NEUTRON_MASS = 1.67492749804e-27